@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 #
 #
-# $Id: Proxy.pm,v 1.13 2007/01/03 00:29:58 lem Exp $
+# $Id: Proxy.pm 75 2009-08-12 22:08:28Z lem $
 
 package Net::Radius::Server::Set::Proxy;
 
@@ -9,7 +9,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = do { sprintf " %d.%03d", (q$Revision: 1.13 $ =~ /\d+/g) };
+our $VERSION = do { sprintf "%0.3f", 1+(q$Revision: 75 $ =~ /\d+/g)[0]/1000 };
 
 use IO::Select;
 use IO::Socket::INET;
@@ -261,7 +261,7 @@ None by default.
 
 =head1 HISTORY
 
-  $Log: Proxy.pm,v $
+  $Log$
   Revision 1.13  2007/01/03 00:29:58  lem
   Improve check for non-responses
 
@@ -280,11 +280,11 @@ Net::Radius::Packet(3).
 
 =head1 AUTHOR
 
-Luis E. Muoz, E<lt>luismunoz@cpan.orgE<gt>
+Luis E. Muñoz, E<lt>luismunoz@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Luis E. Muoz
+Copyright (C) 2006 by Luis E. Muñoz
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl 5.8.6 itself.
